.. image:: https://github.com/danjac/pyramid_storage/actions/workflows/test.yml/badge.svg
        :target: https://github.com/danjac/pyramid_storage/actions

.. image:: https://img.shields.io/pypi/v/pyramid_storage.svg
        :target: https://pypi.python.org/pypi/pyramid_storage


**pyramid_storage** is a package for handling file uploads in your Pyramid framework application.

Links
=====

* Official docs: https://pythonhosted.org/pyramid_storage/

This package was inspired by the `flask-uploads package <https://github.com/srusskih/flask-uploads>`_


Running the tests
=================

To run the unit tests::

  $ make tests


Releasing
=========

1. Create a release on Github on https://github.com/danjac/pyramid_storage/releases/new
2. Create a new tag `X.Y.Z` (*This tag will be created from the target when you publish this release.*)
3. Generate release notes
4. Publish release
